@@ -5,7 +5,7 @@ use warnings;
 use AI::XGBoost::Booster;
 use Exporter::Easy ( OK => ['train'] );
 
-our $VERSION = '0.008';    # VERSION
+our $VERSION = '0.1';    # VERSION
 
 # ABSTRACT: Perl wrapper for XGBoost library L<https://github.com/dmlc/xgboost>
 
@@ -39,7 +39,7 @@ AI::XGBoost - Perl wrapper for XGBoost library L<https://github.com/dmlc/xgboost
 
 =head1 VERSION
 
-version 0.008
+version 0.1
 
 =head1 SYNOPSIS
 
@@ -91,6 +91,23 @@ version 0.008
  # Split train and test, label and features
  my $train_dataset = [map {$iris->{$_}} grep {$_ ne 'species'} keys %$iris];
  my $test_dataset = [map {$iris->{$_}} grep {$_ ne 'species'} keys %$iris];
+ 
+ sub transpose {
+ # Transposing without using PDL, Data::Table, Data::Frame or other modules
+ # to keep minimal dependencies
+     my $array = shift;
+     my @aux = ();
+     for my $row (@$array) {
+         for my $column (0 .. scalar @$row - 1) {
+             push @{$aux[$column]}, $row->[$column];
+         }
+     }
+     return \@aux;
+ }
+ 
+ $train_dataset = transpose($train_dataset);
+ $test_dataset = transpose($test_dataset);
+ 
  my $train_label = [map {$class{$_}} @{$iris->{'species'}}];
  my $test_label = [map {$class{$_}} @{$iris->{'species'}}];
  
@@ -160,10 +177,6 @@ The goal is to make a full wrapper for XGBoost.
 
 =over 4
 
-=item 0.1 
-
-Full raw C API available as L<AI::XGBoost::CAPI::RAW>
-
 =item 0.2 
 
 Full C API "easy" to use, with PDL support as L<AI::XGBoost::CAPI>
@@ -171,6 +184,10 @@ Full C API "easy" to use, with PDL support as L<AI::XGBoost::CAPI>
 Easy means clients don't have to use L<FFI::Platypus> or modules dealing
 with C structures
 
+=item 0.25
+
+Alien package for libxgboost.so/xgboost.dll
+
 =item 0.3
 
 Object oriented API Moose based with DMatrix and Booster classes
@@ -203,11 +220,7 @@ Pablo Rodríguez González <pablo.rodriguez.gonzalez@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Pablo Rodríguez González.
-
-This is free software, licensed under:
-
-  The Apache License, Version 2.0, January 2004
+Copyright (c) 2017 by Pablo Rodríguez González.
 
 =head1 CONTRIBUTOR
 
