@@ -4,7 +4,7 @@ use warnings;
 
 use parent 'NativeCall';
 
-our $VERSION = '0.008';    # VERSION
+our $VERSION = '0.1';    # VERSION
 
 # ABSTRACT: Perl wrapper for XGBoost C API https://github.com/dmlc/xgboost
 
@@ -20,7 +20,9 @@ sub XGDMatrixCreateFromCSCEx : Args(size_t[], uint[], float[], size_t, size_t, s
 
 sub XGDMatrixCreateFromMat : Args(float[], uint64, uint64, float, opaque*) : Native(xgboost) : Returns(int) { }
 
-sub XGDMatrixSliceDMatrix : Args(opaque, int *, uint64, opaque*) : Native(xgboost) : Returns(int) { }
+sub XGDMatrixCreateFromMat_omp : Args(float[], uint64, uint64, float, opaque*, int) : Native(xgboost) : Returns(int) { }
+
+sub XGDMatrixSliceDMatrix : Args(opaque, int[], uint64, opaque*) : Native(xgboost) : Returns(int) { }
 
 sub XGDMatrixNumRow : Args(opaque, uint64*) : Native(xgboost) : Returns(int) { }
 
@@ -78,6 +80,10 @@ sub XGBoosterGetAttr : Args(opaque, string, opaque*, int*) : Native(xgboost) : R
 
 sub XGBoosterGetAttrNames : Args(opaque, uint64*, opaque*) : Native(xgboost) : Returns(int) { }
 
+sub XGBoosterLoadRabitCheckpoint : Args(opaque, int) : Native(xgboost) : Returns(int) { }
+
+sub XGBoosterSaveRabitCheckpoint : Args(opaque) : Native(xgboost) : Returns(int) { }
+
 1;
 
 __END__
@@ -92,7 +98,7 @@ AI::XGBoost::CAPI::RAW - Perl wrapper for XGBoost C API https://github.com/dmlc/
 
 =head1 VERSION
 
-version 0.008
+version 0.1
 
 =head1 SYNOPSIS
 
@@ -276,6 +282,40 @@ created dmatrix
 
 =back
 
+=head2 XGDMatrixCreateFromMat_omp
+
+Create matrix content from dense matrix
+
+Parameters:
+
+=over 4
+
+=item data 
+
+pointer to the data space
+
+=item nrow
+
+number of rows
+
+=item ncol
+
+number columns
+
+=item missing
+
+which value to represent missing value
+
+=item out
+
+created dmatrix
+
+=item nthread
+
+number of threads (up to maximum cores available, if <=0 use all cores)
+
+=back
+
 =head2 XGDMatrixSliceDMatrix
 
 Create a new dmatrix from sliced content of existing matrix
@@ -712,16 +752,16 @@ file name
 
 =head2 XGBoosterGetAttrNames
 
+=head2 XGBoosterLoadRabitCheckpoint
+
+=head2 XGBoosterSaveRabitCheckpoint
+
 =head1 AUTHOR
 
 Pablo Rodríguez González <pablo.rodriguez.gonzalez@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Pablo Rodríguez González.
-
-This is free software, licensed under:
-
-  The Apache License, Version 2.0, January 2004
+Copyright (c) 2017 by Pablo Rodríguez González.
 
 =cut
